@@ -1,11 +1,14 @@
 package PICA::Parser::XML;
 use strict;
+use warnings;
 
-our $VERSION = '0.21';
+our $VERSION = '0.23';
 
 use Carp qw(croak);
 use XML::LibXML::Reader;
 
+use parent 'PICA::Parser::Base';
+
 sub new {
     my ($class, $input) = @_;
 
@@ -17,12 +20,10 @@ sub new {
         binmode $input; # drop all PerlIO layers, as required by libxml2
         my $reader = XML::LibXML::Reader->new(IO => $input)
             or croak "cannot read from filehandle $input\n";
-        $self->{filename}   = scalar $input;
         $self->{xml_reader} = $reader;
     } elsif ( defined $input && $input !~ /\n/ && -e $input ) {
         my $reader = XML::LibXML::Reader->new(location => $input)
             or croak "cannot read from file $input\n";
-        $self->{filename}   = $input;
         $self->{xml_reader} = $reader;
     } elsif ( defined $input && length $input > 0 ) {
         $input = ${$input} if (ref($input) // '' eq 'SCALAR'); 
@@ -36,19 +37,6 @@ sub new {
     $self;
 }
 
-# duplicated in PICA::Data::Plus because no common superclass exists
-sub next {
-    my ($self) = @_;
-
-    # get last subfield from 003@ as id
-    if ( my $record = $self->next_record ) {
-        my ($id) = map { $_->[-1] } grep { $_->[0] =~ '003@' } @{$record};
-        return { _id => $id, record => $record };
-    }
-
-    return;
-}
-
 sub next_record {
     my ($self) = @_;
 
@@ -84,34 +72,10 @@ __END__
 
 PICA::Parser::XML - PICA+ XML parser
 
-=head1 SYNOPSIS
+=head2 DESCRIPTION
 
-    use PICA::Parser::XML;
+See L<PICA::Parser::Base> for synopsis and details.
 
-    my $parser = PICA::Parser::XML->new( $filename );
-
-    while ( my $record_hash = $parser->next ) {
-        # do something
-    }
-
-=head1 METHODS
-
-=head2 new( $input )
-
-Initialize parser to read from a given XML file, handle (e.g. L<IO::Handle>),
-string reference, or XML string.
-
-=head2 next
-
-Reads the next PICA+ record. Returns a hash with keys C<_id> and C<record>.
-
-=head2 next_record
-
-Reads the next PICA+ record. Returns an array of field arrays.
-
-=head1 SEEALSO
-
-L<PICA::XMLParser>, included in the release of L<PICA::Record> implements
-another PICA+ XML format parser, not aligned with the L<Catmandu> framework.
+The counterpart of this module is L<PICA::Writer::XML>.
 
 =cut
